@@ -2,7 +2,9 @@ use strict;
 use warnings;
 package Data::Beacon;
 #ABSTRACT: BEACON format validating parser and serializer
+our $VERSION = '0.3.1'; #VERSION
 
+use 5.008;
 use Time::Piece;
 use Scalar::Util qw(blessed);
 use URI::Escape;
@@ -11,168 +13,6 @@ use Carp;
 use base 'Exporter';
 our @EXPORT = qw(plainbeaconlink beacon);
 
-=head1 DESCRIPTION
-
-THIS MODULE DOES NOT REFLECT THE CURRENT STATE OF BEACON SPECIFICATION!
-
-This package implements a validating L</BEACON format> parser and serializer.
-In short, a "Beacon" is a set of links, together with some meta fields. Each 
-link at least consists of "source" URI (also referred to as "id") and a "target"
-URI. In addition it has a "label" and a "description", which are both Unicode
-strings, being the empty string by default.
-
-=head1 SYNOPSIS
-
-  use Data::Beacon;
-
-  $beacon = beacon();                     # create new Beacon object
-  $beacon = beacon( {                     # create new Beacon with meta fields
-    PREFIX => $p, TARGET => $t, XY => $z
-  } );
-  
-  $beacon = beacon( $filename );          # open file and parse its meta fields
-
-  if ( $b->errors ) {                     # check for errors
-    print STDERR $b->lasterror . "\n"
-    ($msg,$lineno,$line) = $b->lasterror; 
-  }
-
-  $beacon->parse;                         # parse all links from opened file
-  $beacon->parse( links => \&handler );   # parse links, call handler for each
-
-  $beacon->parse( errors => \&handler );  # parse links, on error call handler
-  $beacon->parse( errors => 'print' );    # parse links, print errors to STDERR
-  $beacon->parse( errors => 'warn' );     # parse links, warn on errors
-  $beacon->parse( errors => 'die' );      # parse links, die on errors
-
-  while ( $beacon->nextlink ) {            # parse and iterate all valid links
-    ($source,$label,$descr,$target) = $beacon->link;      # raw link as read
-    ($source,$label,$descr,$target) = $beacon->expanded;  # full link expanded
-  }
-
-  $descr = $beacon->meta( 'DESCRIPTION' );      # get meta field
-  $beacon->meta( DESCRIPTION => 'my links' );   # set meta fields
-  %meta = $beacon->meta;                        # get all meta fields
-
-  print $beacon->metafields;                    # serialize meta fields
-
-
-  $beacon->parse( \$beaconstring );             # parse from string
-  $beacon->parse( sub { return $nextline } );   # parse from callback
-
-  $beacon->count;        # number of parsed links
-
-  
-  $beacon->appendline( $line );
-
-  $beacon->appendlink( $source, $label, $descr, $target );
-
-=head1 BEACON format
-
-B<BEACON format> is the serialization format for Beacons. It defines a very
-condense syntax to express links without having to deal much with technical 
-specifications.
-
-See L<http://gbv.github.com/beaconspec/beacon.html> for a more detailed
-description.
-
-=head1 USAGE
-
-=head2 Serializing
-
-To serialize only BEACON meta fields, create a new Beacon object, and set its
-meta fields (passed to the constructor, or with L</meta>). You can then get 
-the meta fields in BEACON format with L</metafields>:
-
-  my $beacon = beacon( { PREFIX => ..., TARGET => ... } );
-  print $beacon->metafields;
-
-The easiest way to serialize links in BEACON format, is to set your Beacon 
-object's link handler to C<print>, so each link is directly printed to STDOUT.
-
-  my $beacon = beacon( \%metafields, links => 'print' );
-  print $b->metafields();
-
-  while ( ... ) {
-      $beacon->appendlink( $source, $label, $description, $target );
-  }
-
-Alternatively you can use the function L</plainbeaconlink>. In this case you
-should validate links before printing:
-
-  if ( $beacon->appendlink( $source, $label, $description, $target ) ) {
-      print plainbeaconlink( $beacon->link ) . "\n";
-  }
-
-=head2 Parsing
-
-You can parse BEACON format either as iterator:
-
-  my $beacon = beacon( $file );
-  while ( $beacon->nextlink ) {
-      my ($source, $label, $description, $target) = $beacon->link;
-      ...
-  }
-
-Or by push parsing with handler callbacks:
-
-  my $beacon = beacon( $file );
-  $beacon->parse( 'link' => \link_handler );
-  $errors = $beacon->errors;
-
-
-Instead of a filename, you can also provide a scalar reference, to parse
-from a string. The meta fields are parsed immediately:
-
-  my $beacon = beacon( $file );
-  print $beacon->metafields . "\n";
-  my $errors = $beacon->errors;
-
-To quickly parse a BEACON file:
-
-  use Data::Beacon;
-  beacon($file)->parse();
-
-=head2 Querying
-
-Data::Beacon does only read or write links. To store links, use one of
-its subclasses (to be described later).
-
-=head2 Handlers
-
-To handle errors and links, you can pass handler arguments to the constructor
-and to the L</parse> method.
-
-=over
-
-=item C<errors>
-
-By default, errors are silently ignored (C<errors =E<gt> 0>. You should enable
-one of the error handlers C<warn> (errors create a warning with C<carp>), 
-C<die> (errors will let the program die with C<croak>), or C<print> (error 
-messages will be print to STDERR). Alternatively you can provide a custom error
-handler function as code reference. On error this function is provided one to
-three arguments: first an error message, second a line number, and third the
-content of the current line, if the error resulted in parsing a line of BEACON
-format.
-
-=item C<links>
-
-See the L</parse> method for description.
-
-=back
-
-=head1 METHODS
-
-=head2 new ( [ $from ] [, $metafields ] [, $handlers ] )
-
-Create a new Beacon object, optionally from a given file. If you specify a 
-source via C<$from> argument or as handler C<from =E<gt> $from>, it will be
-opened for parsing and all meta fields will immediately be read from it.
-Otherwise a new Beacon object will be created, optionally with given meta
-fields.
-
-=cut
 
 sub new {
     my $class = shift;
@@ -182,17 +22,6 @@ sub new {
     return $self;
 }
 
-=head2 meta ( [ $key [ => $value [ ... ] ] ] )
-
-Get and/or set one or more meta fields. Returns a hash (no arguments),
-or string or undef (one argument), or croaks on invalid arguments. A
-meta field can be unset by setting its value to the empty string.
-The FORMAT field cannot be unset. This method may also croak if a known
-fields, such as FORMAT, PREFIX, FEED, EXAMPLES, REVISIT, TIMESTAMP is
-tried to set to an invalid value. Such an error will not change the
-error counter of this object or modify C<lasterror>.
-
-=cut
 
 sub meta { # TODO: document meta fields
     my $self = shift;
@@ -271,60 +100,27 @@ sub meta { # TODO: document meta fields
     }
 }
 
-=head2 count
-
-If parsing has been started, returns the number of links, successfully read so
-far (or zero). If only the meta fields have been parsed, this returns the value
-of the meta field. In contrast to C<meta('count')>, this method always returns
-a number. Note that all valid links that could be parsed are included, no matter
-if processed by a link handler or not.
-
-=cut
 
 sub count {
     my $count = $_[0]->meta('COUNT');
     return defined $count ? $count : 0;
 }
 
-=head2 line
-
-Returns the current line number or zero.
-
-=cut
 
 sub line {
     return $_[0]->{line};
 }
 
-=head2 lasterror
-
-Returns the last parsing error message (if any). Errors triggered by directly
-calling C<meta> are not included. In list context returns a list of error
-message, line number, and current line content.
-
-=cut
 
 sub lasterror {
     return wantarray ? @{$_[0]->{lasterror}} : $_[0]->{lasterror}->[0];  
 }
 
-=head2 errors
-
-Returns the number of parsing errors or zero.
-
-=cut
 
 sub errors {
     return $_[0]->{errors};
 }
 
-=head2 metafields 
-
-Return all meta fields, serialized and sorted as string. Althugh the order of
-fields is irrelevant, but this implementation always returns the same fields
-in same order. To get all meta fields as hash, use the C<meta> method.
-
-=cut
 
 sub metafields {
     my $self = shift;
@@ -340,63 +136,6 @@ sub metafields {
     return @lines ? join ("\n", @lines) . "\n" : "";
 }
 
-=head2 parse ( [ $from ] { handler => coderef | option => $value } )
-
-Parse all remaining links (push parsing). If provided a C<from> parameter,
-this starts a new Beacon. That means the following three are equivalent:
-
-  $b = new SeeAlso::Beacon( $from );
-
-  $b = new SeeAlso::Beacon( from => $from );
-
-  $b = new SeeAlso::Beacon;
-  $b->parse( $from );
-
-If C<from> is a scalar, it is used as file to parse from. Alternatively you
-can supply a string reference, or a code reference.
-
-The C<pre> option can be used to set some meta fields before parsing starts.
-These fields are cached and reused every time you call C<parse>.
-
-If the C<mtime> option is given, the TIMESTAMP meta value will be initialized
-as last modification time of the given file.
-
-By default, all errors are silently ignored, unless you specifiy an error handler
-The last error can be retrieved with the C<lasterror> method. The current number
-of errors by C<errors>.
-
-Finally, the C<link> handler can be a code reference to a method that is
-called for each link (that is each line in the input that contains a valid
-link). The following arguments are passed to the handler:
-
-=over
-
-=item C<$source>
-
-Link source as given in BEACON format.
-This may be abbreviated but not the empty string.
-
-=item C<$label>
-
-Label as string. This may be the empty string.
-
-=item C<$description>
-
-Description as string. This may be the empty string.
-
-=item C<$target>
-
-Link target as given in BEACON format.
-This may be abbreviated or the empty string.
-
-=back
-
-The number of sucessfully parsed links is returned by C<count>.
-
-Errors in link handler and input handler are catched, and produce an
-error that is given to the error handler.
-
-=cut
 
 sub parse {
     my $self = shift;
@@ -415,14 +154,6 @@ sub parse {
     return $self->errors == 0;
 }
 
-=head2 nextlink
-
-Read from the input stream until the next link has been parsed. Empty lines
-and invalid lines are skipped, but the error handler is called on invalid 
-lines. This method can be used for pull parsing. Always returns either the
-link as list or an empty list if the end of input has been reached.
-
-=cut
 
 sub nextlink {
     my $self = shift;
@@ -443,27 +174,12 @@ sub nextlink {
     return; # EOF
 }
 
-=head2 link
-
-Returns the last valid link, that has been read. The link is returned
-as list of four values (source, label, description, target) without
-expansion. Use the L</expanded> method to get the link with full URIs.
-
-=cut
 
 sub link {
     my $self = shift;
     return @{$self->{link}} if $self->{link};
 }
 
-=head2 expanded
-
-Returns the last valid link, that has been read in expanded form. The 
-link is returned as list of four values (source, label, description, 
-target), possibly expanded by the meta fields PREFIX, TARGET/TARGETPREFIX,
-MESSAGE etc. Use L</expand> to expand an arbitrary link.
-
-=cut
 
 sub expanded {
     my $self = shift;
@@ -476,14 +192,6 @@ sub expanded {
     }
 }
 
-=head2 expand ( $source, $label, $description, $target )
-
-Expand a link, consisting of source (mandatory), and label, description,
-and target (all optional). Returns the expanded link as array with four 
-values, or an empty list. This method does append the link to the Beacon
-object, nor call any handlers.
-
-=cut
 
 sub expand {
     my $self = shift;
@@ -501,13 +209,6 @@ sub expand {
     return @fields;
 }
 
-=head2 expandsource( $source )
-
-Expand the source part of a link, by prepending the PREFIX meta field, if 
-given. This method always returns a string, which is the empty string, if
-the source parameter could not be expanded to a valid URI.
-
-=cut
 
 sub expandsource {
     my ($self, $source) = @_;
@@ -521,14 +222,6 @@ sub expandsource {
     return _is_uri($source) ? $source : ''; 
 }
 
-=head2 appendline( $line )
-
-Append a line of of BEACON format. This method parses the line, and calls the
-link handler, or error handler. In scalar context returns whether a link has
-been read (that can then be accessed with C<link>). In list context, returns
-the parsed link as list, or the empty list, if the line could not be parsed.
-
-=cut
 
 sub appendline {
     my ($self, $line) = @_;
@@ -553,13 +246,6 @@ sub appendline {
     return;
 }
 
-=head2 appendlink ( $source [, $label [, $description [, $target ] ] ] )
-
-Append a link. The link is validated and returned as list of four values.
-On error the error handler is called and an empty list is returned.
-On success the link handler is called.
-
-=cut
 
 sub appendlink {
     my $self = shift;
@@ -620,31 +306,11 @@ sub appendlink {
     return @fields; # TODO: return expanded on request
 }
 
-=head1 FUNCTIONS
-
-The following functions are exported by default.
-
-=head2 beacon ( [ $from ] { handler => coderef } )
-
-Shortcut for C<Data::Beacon-E<gt>new>.
-
-=cut
 
 sub beacon {
     return Data::Beacon->new( @_ );
 }
 
-=head2 plainbeaconlink ( $source, $label, $description, $target )
-
-Serialize a link, consisting of source (mandatory), label, description,
-and target (all optional) as condensed string in BEACON format. This
-function does not check whether the arguments form a valid link or not.
-You can pass a simple link, as returned by the L</link> method, or an
-expanded link, as returned by L</expanded>.
-
-This function will be removed or renamed.
-
-=cut
 
 sub plainbeaconlink {
     shift if ref($_[0]) and UNIVERSAL::isa($_[0],'Data::Beacon');
@@ -671,17 +337,6 @@ sub plainbeaconlink {
     return join('|', @link);
 }
 
-=head1 INTERNAL METHODS
-
-If you directly call any of this methods, puppies will die.
-
-=head2 _initparams ( [ $from ] { handler => coderef | option => value } | $metafield )
-
-Initialize parameters as passed to C<new> or C<parse>. Known parameters
-are C<from>, C<error>, and C<link> (C<from> is not checked here). In 
-addition you cann pass C<pre> and C<mtime> as options.
-
-=cut
 
 sub _initparams {
     my $self = shift;
@@ -732,16 +387,6 @@ sub _initparams {
     $self->{mtime} = $param{mtime};
 }
 
-=head2 _startparsing
-
-Open a BEACON file and parse all meta fields. Calling this method will reset
-the whole object but not the parameters as set with C<_initparams>. If no
-source had been specified (with parameter C<from>), this is all the method 
-does. If a source is given, it is opened and parsed. Parsing stops when the
-first non-empty and non-meta field line is encountered. This line is internally
-stored as lookahead.
-
-=cut
 
 sub _startparsing {
     my $self = shift;
@@ -809,12 +454,6 @@ sub _startparsing {
     } while (defined $line);
 }
 
-=head2 _handle_error ( $msg [, $line ] )
-
-Internal error handler that calls a custom error handler,
-increases the error counter and stores the last error. 
-
-=cut
 
 sub _handle_error {
     my $self = shift;
@@ -844,11 +483,6 @@ our %ERROR_HANDLERS = (
     }
 );
 
-=head2 _readline
-
-Internally read and return a line for parsing afterwards. May trigger an error.
-
-=cut
 
 sub _readline {
     my $self = shift;
@@ -866,13 +500,6 @@ sub _readline {
     }
 }
 
-=head2 _fields
-
-Gets one or more fields, that are strings, which do not contain C<|> or
-newlines. The first string is not empty. Returns a reference to an array
-of four fields.
-
-=cut
 
 sub _fields {
     my $self = shift;
@@ -916,13 +543,6 @@ sub _checklink {
     return undef;
 }
 
-=head2 _expandlink ( $link )
-
-Expand a link, provided as array reference without validation. The link
-must have four defined, trimmed fields. After expansion, source and target
-must still be checked whether they are valid URIs.
-
-=cut
 
 sub _expandlink {
     my ($self, $link) = @_;
@@ -985,12 +605,6 @@ sub _str_replace {
     $_[0] =~ s/\Q$_[1]\E/$_[2]/g;
 }
 
-=head2 _is_uri
-
-Check whether a given string is an URI. This function is based on code of
-L<Data::Validate::URI>, adopted for performance.
-
-=cut
 
 sub _is_uri {
     my $value = $_[0];
@@ -1027,14 +641,397 @@ sub _is_uri {
 
 1;
 
-=head1 DEVELOPMENT
+__END__
 
-Please visit http://github.com/nichtich/p5-data-beacon for the latest
-development snapshot, bug reports, feature requests, and such.
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Data::Beacon - BEACON format validating parser and serializer
+
+=head1 VERSION
+
+version 0.3.1
+
+=head1 SYNOPSIS
+
+  use Data::Beacon;
+
+  $beacon = beacon();                     # create new Beacon object
+  $beacon = beacon( {                     # create new Beacon with meta fields
+    PREFIX => $p, TARGET => $t, XY => $z
+  } );
+  
+  $beacon = beacon( $filename );          # open file and parse its meta fields
+
+  if ( $b->errors ) {                     # check for errors
+    print STDERR $b->lasterror . "\n"
+    ($msg,$lineno,$line) = $b->lasterror; 
+  }
+
+  $beacon->parse;                         # parse all links from opened file
+  $beacon->parse( links => \&handler );   # parse links, call handler for each
+
+  $beacon->parse( errors => \&handler );  # parse links, on error call handler
+  $beacon->parse( errors => 'print' );    # parse links, print errors to STDERR
+  $beacon->parse( errors => 'warn' );     # parse links, warn on errors
+  $beacon->parse( errors => 'die' );      # parse links, die on errors
+
+  while ( $beacon->nextlink ) {            # parse and iterate all valid links
+    ($source,$label,$descr,$target) = $beacon->link;      # raw link as read
+    ($source,$label,$descr,$target) = $beacon->expanded;  # full link expanded
+  }
+
+  $descr = $beacon->meta( 'DESCRIPTION' );      # get meta field
+  $beacon->meta( DESCRIPTION => 'my links' );   # set meta fields
+  %meta = $beacon->meta;                        # get all meta fields
+
+  print $beacon->metafields;                    # serialize meta fields
+
+
+  $beacon->parse( \$beaconstring );             # parse from string
+  $beacon->parse( sub { return $nextline } );   # parse from callback
+
+  $beacon->count;        # number of parsed links
+
+  
+  $beacon->appendline( $line );
+
+  $beacon->appendlink( $source, $label, $descr, $target );
+
+=head1 DESCRIPTION
+
+THIS MODULE DOES NOT REFLECT THE CURRENT STATE OF BEACON SPECIFICATION!
+
+This package implements a validating L</BEACON format> parser and serializer.
+In short, a "Beacon" is a set of links, together with some meta fields. Each 
+link at least consists of "source" URI (also referred to as "id") and a "target"
+URI. In addition it has a "label" and a "description", which are both Unicode
+strings, being the empty string by default.
+
+=head1 BEACON format
+
+B<BEACON format> is the serialization format for Beacons. It defines a very
+condense syntax to express links without having to deal much with technical 
+specifications.
+
+See L<http://gbv.github.com/beaconspec/beacon.html> for a more detailed
+description.
+
+=head1 USAGE
+
+=head2 Serializing
+
+To serialize only BEACON meta fields, create a new Beacon object, and set its
+meta fields (passed to the constructor, or with L</meta>). You can then get 
+the meta fields in BEACON format with L</metafields>:
+
+  my $beacon = beacon( { PREFIX => ..., TARGET => ... } );
+  print $beacon->metafields;
+
+The easiest way to serialize links in BEACON format, is to set your Beacon 
+object's link handler to C<print>, so each link is directly printed to STDOUT.
+
+  my $beacon = beacon( \%metafields, links => 'print' );
+  print $b->metafields();
+
+  while ( ... ) {
+      $beacon->appendlink( $source, $label, $description, $target );
+  }
+
+Alternatively you can use the function L</plainbeaconlink>. In this case you
+should validate links before printing:
+
+  if ( $beacon->appendlink( $source, $label, $description, $target ) ) {
+      print plainbeaconlink( $beacon->link ) . "\n";
+  }
+
+=head2 Parsing
+
+You can parse BEACON format either as iterator:
+
+  my $beacon = beacon( $file );
+  while ( $beacon->nextlink ) {
+      my ($source, $label, $description, $target) = $beacon->link;
+      ...
+  }
+
+Or by push parsing with handler callbacks:
+
+  my $beacon = beacon( $file );
+  $beacon->parse( 'link' => \link_handler );
+  $errors = $beacon->errors;
+
+Instead of a filename, you can also provide a scalar reference, to parse
+from a string. The meta fields are parsed immediately:
+
+  my $beacon = beacon( $file );
+  print $beacon->metafields . "\n";
+  my $errors = $beacon->errors;
+
+To quickly parse a BEACON file:
+
+  use Data::Beacon;
+  beacon($file)->parse();
+
+=head2 Querying
+
+Data::Beacon does only read or write links. To store links, use one of
+its subclasses (to be described later).
+
+=head2 Handlers
+
+To handle errors and links, you can pass handler arguments to the constructor
+and to the L</parse> method.
+
+=over
+
+=item C<errors>
+
+By default, errors are silently ignored (C<errors =E<gt> 0>. You should enable
+one of the error handlers C<warn> (errors create a warning with C<carp>), 
+C<die> (errors will let the program die with C<croak>), or C<print> (error 
+messages will be print to STDERR). Alternatively you can provide a custom error
+handler function as code reference. On error this function is provided one to
+three arguments: first an error message, second a line number, and third the
+content of the current line, if the error resulted in parsing a line of BEACON
+format.
+
+=item C<links>
+
+See the L</parse> method for description.
+
+=back
+
+=head1 METHODS
+
+=head2 new ( [ $from ] [, $metafields ] [, $handlers ] )
+
+Create a new Beacon object, optionally from a given file. If you specify a 
+source via C<$from> argument or as handler C<from =E<gt> $from>, it will be
+opened for parsing and all meta fields will immediately be read from it.
+Otherwise a new Beacon object will be created, optionally with given meta
+fields.
+
+=head2 meta ( [ $key [ => $value [ ... ] ] ] )
+
+Get and/or set one or more meta fields. Returns a hash (no arguments),
+or string or undef (one argument), or croaks on invalid arguments. A
+meta field can be unset by setting its value to the empty string.
+The FORMAT field cannot be unset. This method may also croak if a known
+fields, such as FORMAT, PREFIX, FEED, EXAMPLES, REVISIT, TIMESTAMP is
+tried to set to an invalid value. Such an error will not change the
+error counter of this object or modify C<lasterror>.
+
+=head2 count
+
+If parsing has been started, returns the number of links, successfully read so
+far (or zero). If only the meta fields have been parsed, this returns the value
+of the meta field. In contrast to C<meta('count')>, this method always returns
+a number. Note that all valid links that could be parsed are included, no matter
+if processed by a link handler or not.
+
+=head2 line
+
+Returns the current line number or zero.
+
+=head2 lasterror
+
+Returns the last parsing error message (if any). Errors triggered by directly
+calling C<meta> are not included. In list context returns a list of error
+message, line number, and current line content.
+
+=head2 errors
+
+Returns the number of parsing errors or zero.
+
+=head2 metafields 
+
+Return all meta fields, serialized and sorted as string. Althugh the order of
+fields is irrelevant, but this implementation always returns the same fields
+in same order. To get all meta fields as hash, use the C<meta> method.
+
+=head2 parse ( [ $from ] { handler => coderef | option => $value } )
+
+Parse all remaining links (push parsing). If provided a C<from> parameter,
+this starts a new Beacon. That means the following three are equivalent:
+
+  $b = new SeeAlso::Beacon( $from );
+
+  $b = new SeeAlso::Beacon( from => $from );
+
+  $b = new SeeAlso::Beacon;
+  $b->parse( $from );
+
+If C<from> is a scalar, it is used as file to parse from. Alternatively you
+can supply a string reference, or a code reference.
+
+The C<pre> option can be used to set some meta fields before parsing starts.
+These fields are cached and reused every time you call C<parse>.
+
+If the C<mtime> option is given, the TIMESTAMP meta value will be initialized
+as last modification time of the given file.
+
+By default, all errors are silently ignored, unless you specifiy an error handler
+The last error can be retrieved with the C<lasterror> method. The current number
+of errors by C<errors>.
+
+Finally, the C<link> handler can be a code reference to a method that is
+called for each link (that is each line in the input that contains a valid
+link). The following arguments are passed to the handler:
+
+=over
+
+=item C<$source>
+
+Link source as given in BEACON format.
+This may be abbreviated but not the empty string.
+
+=item C<$label>
+
+Label as string. This may be the empty string.
+
+=item C<$description>
+
+Description as string. This may be the empty string.
+
+=item C<$target>
+
+Link target as given in BEACON format.
+This may be abbreviated or the empty string.
+
+=back
+
+The number of sucessfully parsed links is returned by C<count>.
+
+Errors in link handler and input handler are catched, and produce an
+error that is given to the error handler.
+
+=head2 nextlink
+
+Read from the input stream until the next link has been parsed. Empty lines
+and invalid lines are skipped, but the error handler is called on invalid 
+lines. This method can be used for pull parsing. Always returns either the
+link as list or an empty list if the end of input has been reached.
+
+=head2 link
+
+Returns the last valid link, that has been read. The link is returned
+as list of four values (source, label, description, target) without
+expansion. Use the L</expanded> method to get the link with full URIs.
+
+=head2 expanded
+
+Returns the last valid link, that has been read in expanded form. The 
+link is returned as list of four values (source, label, description, 
+target), possibly expanded by the meta fields PREFIX, TARGET/TARGETPREFIX,
+MESSAGE etc. Use L</expand> to expand an arbitrary link.
+
+=head2 expand ( $source, $label, $description, $target )
+
+Expand a link, consisting of source (mandatory), and label, description,
+and target (all optional). Returns the expanded link as array with four 
+values, or an empty list. This method does append the link to the Beacon
+object, nor call any handlers.
+
+=head2 expandsource( $source )
+
+Expand the source part of a link, by prepending the PREFIX meta field, if 
+given. This method always returns a string, which is the empty string, if
+the source parameter could not be expanded to a valid URI.
+
+=head2 appendline( $line )
+
+Append a line of of BEACON format. This method parses the line, and calls the
+link handler, or error handler. In scalar context returns whether a link has
+been read (that can then be accessed with C<link>). In list context, returns
+the parsed link as list, or the empty list, if the line could not be parsed.
+
+=head2 appendlink ( $source [, $label [, $description [, $target ] ] ] )
+
+Append a link. The link is validated and returned as list of four values.
+On error the error handler is called and an empty list is returned.
+On success the link handler is called.
+
+=head1 FUNCTIONS
+
+The following functions are exported by default.
+
+=head2 beacon ( [ $from ] { handler => coderef } )
+
+Shortcut for C<Data::Beacon-E<gt>new>.
+
+=head2 plainbeaconlink ( $source, $label, $description, $target )
+
+Serialize a link, consisting of source (mandatory), label, description,
+and target (all optional) as condensed string in BEACON format. This
+function does not check whether the arguments form a valid link or not.
+You can pass a simple link, as returned by the L</link> method, or an
+expanded link, as returned by L</expanded>.
+
+This function will be removed or renamed.
+
+=head1 INTERNAL METHODS
+
+If you directly call any of this methods, puppies will die.
+
+=head2 _initparams ( [ $from ] { handler => coderef | option => value } | $metafield )
+
+Initialize parameters as passed to C<new> or C<parse>. Known parameters
+are C<from>, C<error>, and C<link> (C<from> is not checked here). In 
+addition you cann pass C<pre> and C<mtime> as options.
+
+=head2 _startparsing
+
+Open a BEACON file and parse all meta fields. Calling this method will reset
+the whole object but not the parameters as set with C<_initparams>. If no
+source had been specified (with parameter C<from>), this is all the method 
+does. If a source is given, it is opened and parsed. Parsing stops when the
+first non-empty and non-meta field line is encountered. This line is internally
+stored as lookahead.
+
+=head2 _handle_error ( $msg [, $line ] )
+
+Internal error handler that calls a custom error handler,
+increases the error counter and stores the last error. 
+
+=head2 _readline
+
+Internally read and return a line for parsing afterwards. May trigger an error.
+
+=head2 _fields
+
+Gets one or more fields, that are strings, which do not contain C<|> or
+newlines. The first string is not empty. Returns a reference to an array
+of four fields.
+
+=head2 _expandlink ( $link )
+
+Expand a link, provided as array reference without validation. The link
+must have four defined, trimmed fields. After expansion, source and target
+must still be checked whether they are valid URIs.
+
+=head2 _is_uri
+
+Check whether a given string is an URI. This function is based on code of
+L<Data::Validate::URI>, adopted for performance.
 
 =head1 SEE ALSO
 
 See also L<SeeAlso::Server> for an API to exchange single sets of 
 beacon links, based on the same source identifier.
 
+=head1 AUTHOR
+
+Jakob Voß
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Jakob Voß.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
